@@ -623,33 +623,84 @@ class AIIA:
             if len(self._recent_logs) > 10000:
                 self._recent_logs = set(list(self._recent_logs)[-5000:])
 
-            if not workflow_id and context_id and context_type:
-                workflow_key = f"{context_type}:{context_id}"
+            # === LÓGICA DE WORKFLOW COHERENTE ===
+            if not workflow_id:
+                # Generar workflow_id basado en empresa/dominio para mantener coherencia
+                company_domain = None
+                company_name = None
+                
+                # Extraer dominio de empresa del contexto
+                if isinstance(context, dict):
+                    # Buscar email en el contexto para extraer dominio
+                    for key, value in context.items():
+                        if isinstance(value, str) and '@' in value and '.' in value:
+                            try:
+                                domain_parts = tldextract.extract(value.split('@')[1])
+                                if domain_parts.domain and domain_parts.suffix:
+                                    company_domain = f"{domain_parts.domain}.{domain_parts.suffix}"
+                                    break
+                            except:
+                                continue
+                    
+                    # Buscar company_name directamente
+                    company_name = context.get('company_name') or context.get('company') or context.get('organization')
+                
+                # Si no hay dominio, usar context_id y context_type como fallback
+                if not company_domain and context_id and context_type:
+                    company_domain = f"{context_type}_{context_id}"
+                
+                # Generar workflow_key basado en empresa/dominio
+                if company_domain:
+                    workflow_key = f"company_{company_domain}"
+                elif company_name:
+                    workflow_key = f"org_{company_name.lower().replace(' ', '_')}"
+                else:
+                    # Fallback: usar IA ID para agrupar por desarrollador
+                    workflow_key = f"ia_{self.ia_id}"
+                
+                # Inicializar cache si no existe
                 if not hasattr(self, "_workflow_cache"):
                     self._workflow_cache = {}
                 
+                # Buscar o crear workflow para esta empresa/contexto
                 if workflow_key in self._workflow_cache:
+                    # Usar workflow existente para esta empresa
                     workflow_data = self._workflow_cache[workflow_key]
                     workflow_id = workflow_data["workflow_id"]
+                    
+                    # Incrementar step number
                     if workflow_step_number is None:
                         workflow_step_number = workflow_data.get("step", 0) + 1
                     
-                    if not workflow_step and context_action:
-                        workflow_step = f"{context_action}_{workflow_step_number}"
-                else:
-                    workflow_id = str(uuid.uuid4())
-                    if workflow_step_number is None:
-                        workflow_step_number = 1
-                    if not workflow_step and context_action:
-                        workflow_step = f"{context_action}_1"
+                    # Generar step name coherente
+                    if not workflow_step:
+                        if context_action:
+                            workflow_step = f"step_{workflow_step_number}"
+                        else:
+                            workflow_step = f"step_{workflow_step_number}"
+                            
+                    # Actualizar cache con nuevo step
+                    self._workflow_cache[workflow_key]["step"] = workflow_step_number
+                    self._workflow_cache[workflow_key]["last_action"] = action_code
+                    self._workflow_cache[workflow_key]["timestamp"] = datetime.now(timezone.utc).isoformat()
                     
-                self._workflow_cache[workflow_key] = {
-                    "workflow_id": workflow_id,
-                    "step": workflow_step_number or 1,
-                    "last_action": context_action,
-                    "timestamp": datetime.now(timezone.utc).isoformat()
-                }
+                else:
+                    # Crear nuevo workflow para esta empresa
+                    workflow_id = f"wf_{uuid.uuid4().hex[:8]}"
+                    workflow_step_number = 1
+                    workflow_step = "step_1"
+                    
+                    # Guardar en cache
+                    self._workflow_cache[workflow_key] = {
+                        "workflow_id": workflow_id,
+                        "step": workflow_step_number,
+                        "last_action": action_code,
+                        "company_domain": company_domain,
+                        "company_name": company_name,
+                        "timestamp": datetime.now(timezone.utc).isoformat()
+                    }
                 
+                # Limpiar cache si crece demasiado
                 if len(self._workflow_cache) > 1000:
                     sorted_cache = sorted(
                         self._workflow_cache.items(),
@@ -724,11 +775,14 @@ class AIIA:
                 "registered": registered
             }
             
-            # Agregar información auto-detectada de empresa
+            # Agregar información auto-detectada de empresa a context_public
+            # para que el backend la encuentre correctamente
             if user_email:
-                log_payload["user_email"] = user_email
+                public_context["user_email"] = user_email
             if company_name:
-                log_payload["company_name"] = company_name
+                public_context["company_name"] = company_name
+            if domain:
+                public_context["domain"] = domain
             
             # Add company email for log association if available
             # Removed company_email parameter
